from django import forms
from django.forms import ModelForm, TextInput, Textarea
from django.contrib.auth.forms import AuthenticationForm
from django.contrib.auth.models import User
from django.core.exceptions import ValidationError
from .models import Articles, Materials


class UsersValidationsForm(AuthenticationForm, forms.ModelForm):
    class Meta:
        model = User
        fields = ('username', 'password')

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        for field in self.fields:
            self.fields[field].widget.attrs['class'] = 'form-control'


class UsersRegistrationForm(forms.ModelForm):
    class Meta:
        model = User
        fields = ('username', 'password', 'first_name', 'last_name')
    
    def clean_first_name(self):
        first_name = self.cleaned_data['first_name']
        alfabet = 'абвгдеёжзийклмнопрстуфхцчшщъыьэюя'
        if first_name == '':
            raise ValidationError('Вы не ввели своё имя')
        for i in range(len(first_name)):
            if i == 0 and first_name[i] not in alfabet.upper():
                raise ValidationError('Имя начинается не с заглавной буквы или содержит недопустимые символы')
            elif i != 0 and first_name[i] not in alfabet:
                raise ValidationError('Имя в середине содержит заглавную букву или недопустимые символы')
        return first_name

    def clean_last_name(self):
        last_name = self.cleaned_data['last_name']
        alfabet = 'абвгдеёжзийклмнопрстуфхцчшщъыьэюя'
        if last_name == '':
            raise ValidationError('Вы не ввели свою Фамилию')
        for i in range(len(last_name)):
            if i == 0 and last_name[i] not in alfabet.upper():
                raise ValidationError('Фамилия начинается не с заглавной буквы или содержит недопустимые символы')
            elif i != 0 and last_name[i] not in alfabet:
                raise ValidationError('Фамилия в середине содержит заглавную букву или недопустимые символы')
        return last_name

    def save(self, commit=True):
        user = super().save(commit=False)
        user.set_password(self.cleaned_data["password"])
        if commit:
            user.save()
            if hasattr(self, "save_m2m"):
                self.save_m2m()
        return user

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        for field in self.fields:
            self.fields[field].widget.attrs['class'] = 'form-control'


class CreationForm(ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['stage'].empty_label = 'Этап не выбран'        

    class Meta:
        model = Articles
        fields = ('title', 'stage', 'stage_date', 'article_text_1', 'article_text_2', 'article_text_3', 'article_text_4', 'photo_1', 'photo_2', 'photo_3')
    
    def clean_photo_1(self):
        photo_1 = self.cleaned_data['photo_1']
        if photo_1 != None:
            if photo_1.size > 1048576:
                raise ValidationError('Файл весит больше 1Мб')
        return photo_1

    def clean_photo_2(self):
        photo_2 = self.cleaned_data['photo_2']
        if photo_2 != None:
            if photo_2.size > 1048576:
                raise ValidationError('Файл весит больше 1Мб')
        return photo_2

    def clean_photo_3(self):
        photo_3 = self.cleaned_data['photo_3']
        if photo_3 != None:
            if photo_3.size > 1048576:
                raise ValidationError('Файл весит больше 1Мб')
        return photo_3

    def clean_stage_date(self):
        nums = '1234567890'
        stage_date = self.cleaned_data['stage_date']
        for i in stage_date:
            if i not in nums:
                raise ValidationError('Введённый год содержит что-то ещё кроме чисел')
        return stage_date

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        for field in self.fields:
            self.fields[field].widget.attrs['class'] = 'form-control'

class CreationMaterial(ModelForm):
    class Meta:
        model = Materials
        fields = ('name', 'material')
    
    def clean_material(self):
        material = self.cleaned_data['material']
        if material != None:
            if material.size > 1048576 * 4:
                raise ValidationError('Файл весит больше 4Мб')
        return material

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        for field in self.fields:
            self.fields[field].widget.attrs['class'] = 'form-control'
