from django.db import models
from django.contrib.auth.models import User


class Articles(models.Model):
    author = models.ForeignKey(User, on_delete=models.PROTECT, verbose_name='Автор отзыва', blank=True, null=True)
    author_first_name = models.CharField(max_length=120, verbose_name='Имя автора отзыва', blank=True, null=True)
    author_last_name = models.CharField(max_length=120, verbose_name='Фамилия автора отзыва', blank=True, null=True)
    title = models.CharField(max_length=120, verbose_name='Заголовок отзыва')
    date = models.DateTimeField(auto_now=True)
    stage = models.ForeignKey('Stage', on_delete=models.PROTECT, verbose_name='Этап')
    stage_date = models.CharField(max_length=4, verbose_name='Год этапа')
    article_text_1 = models.TextField(verbose_name='Первая часть текста к отзыву')
    photo_1 = models.ImageField(upload_to="photos/%Y/%m/%d", verbose_name='Первое фото к отзыву(Необязательное поле)',
                                blank=True)
    article_text_2 = models.TextField(verbose_name='Вторая часть текста к отзыву(Необязательное поле)', blank=True)
    photo_2 = models.ImageField(upload_to="photos/%Y/%m/%d", verbose_name='Второе фото к отзыву(Необязательное поле)',
                                blank=True)
    article_text_3 = models.TextField(verbose_name='Третья часть текста к отзыву(Необязательное поле)', blank=True)
    photo_3 = models.ImageField(upload_to="photos/%Y/%m/%d", verbose_name='Третье фото к отзыву(Необязательное поле)',
                                blank=True)
    article_text_4 = models.TextField(verbose_name='Третья часть текста к отзыву(Необязательное поле)', blank=True)

    def __str__(self):
        return self.title

    class Meta:
        verbose_name = 'Статья'
        verbose_name_plural = 'Статьи'


class Stage(models.Model):
    stage = models.CharField(max_length=200, db_index=True, verbose_name='Название этапа')

    def __str__(self):
        return self.stage

    class Meta:
        verbose_name = 'Этап'
        verbose_name_plural = 'Этапы'

class Materials(models.Model):
    author = models.ForeignKey(User, on_delete = models.PROTECT, verbose_name = 'Автор материала', blank = True, null = True)
    author_first_name = models.CharField(max_length = 120, verbose_name = 'Имя автора материала', blank = True, null = True)
    author_last_name = models.CharField(max_length = 120, verbose_name = 'Фамилия автора материала', blank = True, null = True)
    name = models.CharField(max_length = 120, verbose_name = 'Имя материала')
    date = models.DateTimeField(auto_now=True)
    material = models.FileField(upload_to = "materials/%Y/%m/%d", verbose_name = 'Файл')

    def __str__(self):
        return self.name

    class Meta:
        verbose_name = 'Материал'
        verbose_name_plural = 'Материалы'
