from django.urls import path
from . import views
from django.conf import settings
from django.conf.urls.static import static
from django.views.generic import ListView
from .models import Articles, Materials



urlpatterns = [
    path('', views.index, name='home'),
    path("about-us", views.about, name='about'),
    path("forum", ListView.as_view(queryset=Articles.objects.all().order_by('-date'), template_name='main/forum.html'),
         name='forum'),
    path("forum/create", views.CreateArticleView.as_view(), name="create"),
    path("forum/<int:pk>", views.ArticleDetailView.as_view(template_name='main/article.html'), name="article"),
    path("forum/update/<int:pk>", views.UpdateArticleView.as_view(), name="update"),
    path("forum/delete/<int:pk>", views.DeleteArticle, name="delete"),
    path("login", views.SiteLoginView.as_view(), name='login'),
    path("sign_up", views.SiteRegisterView.as_view(), name="sign_up"),
    path("logout", views.SiteLogout.as_view(), name='logout'),
    path("profile", views.profile, name="profile"),
    path('profile/<int:pk>', views.ProfileArticleDetailView.as_view(template_name='main/author_article.html'),
         name='author_article'),
    path("materials", ListView.as_view(queryset = Materials.objects.all().order_by('-date'), template_name = 'main/materials.html'), name='materials'),
    path("materials/create", views.CreateMaterialView.as_view(), name="create_material"),
    path("materials/update/<int:pk>", views.UpdateMaterialView.as_view(), name="update_material"),
    path("materials/delete/<int:pk>", views.DeleteMaterial, name="delete_material"),
]

handler404 = 'main.views.pageNotFound'

if settings.DEBUG:
    urlpatterns += static(settings.STATIC_URL, document_root=settings.STATIC_ROOT)
    urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
