from django.shortcuts import render, redirect
from .forms import CreationForm, CreationMaterial
from .models import Articles, Materials
from django.contrib.auth.views import LoginView, LogoutView
from django.views.generic import DetailView, UpdateView, CreateView
from django.contrib.auth.models import User
from .forms import UsersValidationsForm, UsersRegistrationForm
from django.urls import reverse, reverse_lazy
from django.contrib.auth import authenticate, login
from django.contrib.auth.mixins import LoginRequiredMixin


def index(request):
    return render(request, 'main/index.html')


def about(request):
    return render(request, 'main/about.html')


class CreateArticleView(LoginRequiredMixin, CreateView):
    model = Articles
    template_name = 'main/create.html'
    form_class = CreationForm
    success_url = reverse_lazy('forum')
    login_url = reverse_lazy('login')

    def form_valid(self, form):
        self.object = form.save(commit=False)
        get_info = User.objects.get(username=self.request.user)
        self.object.author_first_name = get_info.first_name
        self.object.author_last_name = get_info.last_name
        print(get_info.first_name, get_info.last_name)
        self.object.author = self.request.user
        self.object.save()
        return super().form_valid(form)


class ArticleDetailView(DetailView):
    model = Articles
    context_object_name = 'article'


class ProfileArticleDetailView(DetailView):
    model = Articles
    context_object_name = 'article'


class UpdateArticleView(LoginRequiredMixin, UpdateView):
    model = Articles
    template_name = 'main/update.html'
    form_class = CreationForm
    success_url = reverse_lazy('profile')
    login_url = reverse_lazy('login')

    def get_form_kwargs(self):
        kwargs = super().get_form_kwargs()
        if self.request.user != kwargs['instance'].author:
            return self.handle_no_permission()
        return kwargs


def DeleteArticle(request, pk):
    get_id = Articles.objects.get(pk=pk)
    if get_id.author == request.user:
        get_id.delete()
        return redirect(reverse('profile'))
    else:
        return render(request, 'main/403.html')


class CreateMaterialView(LoginRequiredMixin, CreateView):
    model = Materials
    template_name = 'main/create_material.html'
    form_class = CreationMaterial
    success_url = reverse_lazy('materials')
    login_url = reverse_lazy('login')
    
    def form_valid(self, form):
        self.object = form.save(commit=False)
        get_info = User.objects.get(username = self.request.user)
        self.object.author_first_name = get_info.first_name
        self.object.author_last_name = get_info.last_name
        self.object.author = self.request.user
        self.object.save()
        return super().form_valid(form)


class UpdateMaterialView(LoginRequiredMixin, UpdateView):
    model = Materials
    template_name = 'main/update_material.html'
    form_class = CreationMaterial
    success_url = reverse_lazy('profile')
    login_url = reverse_lazy('login')
    
    def get_form_kwargs(self):
        kwargs = super().get_form_kwargs()
        if self.request.user != kwargs['instance'].author:
            return self.handle_no_permission()
        return kwargs


def DeleteMaterial(request, pk):
    get_id = Materials.objects.get(pk=pk)
    if get_id.author == request.user:
        get_id.delete()
        return redirect(reverse('profile'))
    else:
        return render(request, 'main/403.html')


def profile(request):
    articles = Articles.objects.order_by('-date')
    materials = Materials.objects.order_by('-date')
    return render(request, 'main/profile.html', {'articles': articles, 'materials' : materials})


class SiteLoginView(LoginView):
    template_name = 'main/login.html'
    form_class = UsersValidationsForm
    success_url = reverse_lazy('home')

    def get_success_url(self):
        return self.success_url


class SiteRegisterView(CreateView):
    model = User
    template_name = 'main/sign_up.html'
    form_class = UsersRegistrationForm
    success_url = reverse_lazy('home')

    def form_valid(self, form):
        form_valid = super().form_valid(form)
        username = form.cleaned_data["username"]
        password = form.cleaned_data["password"]
        first_name = form.cleaned_data["first_name"]
        last_name = form.cleaned_data["last_name"]
        authenticateion_user = authenticate(username=username, password=password, first_name=first_name,
                                            last_name=last_name)
        login(self.request, authenticateion_user)
        return form_valid


class SiteLogout(LogoutView):
    next_page = reverse_lazy('home')


def pageNotFound(request, exception):
    return render(request, 'main/404.html')
